TempDir

Struct TempDir 

pub struct TempDir { /* private fields */ }
Managed temporary directory. All contents are cleaned up on drop.

Implementations

Source

impl TempDir

pub fn new() -> AppResult<Self>

Create a new temporary directory.

pub fn path(&self) -> &Path

The path to this temporary directory.

pub fn child(&self, rel_path: impl AsRef<Path>) -> AppResult<PathBuf>

Create a child path within this temp directory.

pub fn write_file( &self, rel_path: impl AsRef<Path>, content: &[u8], ) -> AppResult<PathBuf>

Write a file at a relative path within this temp directory.

pub fn create_file(&self, name: &str) -> AppResult<TempFile>

Create a named file inside this temp directory.

pub fn create_file_with_extension(&self, ext: &str) -> AppResult<TempFile>

Create a file with the given extension inside this temp directory.