pub struct TempDir { /* private fields */ }Expand description
Managed temporary directory. All contents are cleaned up on drop.
Implementations
Sourceimpl TempDir
impl TempDir
Sourcepub fn child(&self, rel_path: impl AsRef<Path>) -> AppResult<PathBuf>
pub fn child(&self, rel_path: impl AsRef<Path>) -> AppResult<PathBuf>
Create a child path within this temp directory.
Sourcepub fn write_file(
&self,
rel_path: impl AsRef<Path>,
content: &[u8],
) -> AppResult<PathBuf>
pub fn write_file( &self, rel_path: impl AsRef<Path>, content: &[u8], ) -> AppResult<PathBuf>
Write a file at a relative path within this temp directory.
Sourcepub fn create_file(&self, name: &str) -> AppResult<TempFile>
pub fn create_file(&self, name: &str) -> AppResult<TempFile>
Create a named file inside this temp directory.
Sourcepub fn create_file_with_extension(&self, ext: &str) -> AppResult<TempFile>
pub fn create_file_with_extension(&self, ext: &str) -> AppResult<TempFile>
Create a file with the given extension inside this temp directory.